==> biomod2_4.2-5-2.tar.gz: biomod2/R/DEPRECATED.R <==
#' @title Deprecated functions in package \pkg{biomod2}.
#' @description The functions listed below are deprecated and were removed
#' in the current version. When possible, alternative functions with similar
#'   functionality are mentioned. Help pages for deprecated functions are
#'   available at \code{help("<function>-deprecated")}.
#' @name biomod2-deprecated
#' @keywords internal
#' 
#'
NULL

#' @title BIOMOD_CrossValidation
#' @description Deprecated function name for
#'   \code{\link{bm_CrossValidation}}
#' @param ... Additional arguments
#'
#' @name BIOMOD_CrossValidation-deprecated
#' @usage BIOMOD_CrossValidation(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{BIOMOD_CrossValidation}:
#' For \code{BIOMOD_CrossValidation} use \code{\link{bm_CrossValidation}}.
#'
#' @export
BIOMOD_CrossValidation <- function(...) { .Deprecated("bm_CrossValidation") }

#' @title BIOMOD_PresenceOnly
#' @description Deprecated function name for
#'   \code{\link{bm_FindOptimStat}}
#' @param ... Additional arguments
#'
#' @name BIOMOD_PresenceOnly-deprecated
#' @usage BIOMOD_PresenceOnly(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{BIOMOD_PresenceOnly}:
#' For \code{BIOMOD_PresenceOnly} use \code{\link{bm_FindOptimStat}}.
#'
#' @export
BIOMOD_PresenceOnly <- function(...) { .Deprecated("bm_FindOptimStat") }

#' @title BIOMOD_Tuning
#' @description Deprecated function name for
#'   \code{\link{bm_Tuning}}
#' @param ... Additional arguments
#'
#' @name BIOMOD_tuning-deprecated
#' @usage BIOMOD_Tuning(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{BIOMOD_Tuning}:
#' For \code{BIOMOD_Tuning} use \code{\link{bm_Tuning}}.
#'
#' @export
BIOMOD_Tuning <- function(...) { .Deprecated("bm_Tuning") }

#' @title BinaryTransformation
#' @description Deprecated function name for
#'   \code{\link{bm_BinaryTransformation}}
#' @param ... Additional arguments
#'
#' @name BinaryTransformation-deprecated
#' @usage BinaryTransformation(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{BinaryTransformation}:
#' For \code{BinaryTransformation} use \code{\link{bm_BinaryTransformation}}.
#'
#' @export
BinaryTransformation <- function(...) { .Deprecated("bm_BinaryTransformation") }

#' @title calculate.stat
#' @description Deprecated function name for
#'   \code{\link{bm_CalculateStat}}
#' @param ... Additional arguments
#'
#' @name calculate.stat-deprecated
#' @usage calculate.stat(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{calculate.stat}:
#' For \code{calculate.stat} use \code{\link{bm_CalculateStat}}.
#'
#' @export
calculate.stat <- function(...) { .Deprecated("bm_CalculateStat") }

#' @title Find.Optim.Stat
#' @description Deprecated function name for
#'   \code{\link{bm_FindOptimStat}}
#' @param ... Additional arguments
#'
#' @name Find.Optim.Stat-deprecated
#' @usage Find.Optim.Stat(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{Find.Optim.Stat}:
#' For \code{Find.Optim.Stat} use \code{\link{bm_FindOptimStat}}.
#'
#' @export
Find.Optim.Stat <- function(...) { .Deprecated("bm_FindOptimStat") }

#' @title getStatOptimValue
#' @description Deprecated function name for
#'   \code{\link{get_optim_value}}
#' @param ... Additional arguments
#'
#' @name getStatOptimValue-deprecated
#' @usage getStatOptimValue(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{getStatOptimValue}:
#' For \code{getStatOptimValue} use \code{\link{get_optim_value}}.
#'
#' @export
getStatOptimValue <- function(...) { .Deprecated("get_optim_value") }

#' @title makeFormula
#' @description Deprecated function name for
#'   \code{\link{bm_MakeFormula}}
#' @param ... Additional arguments
#'
#' @name makeFormula-deprecated
#' @usage makeFormula(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{makeFormula}:
#' For \code{makeFormula} use \code{\link{bm_MakeFormula}}.
#'
#' @export
makeFormula <- function(...) { .Deprecated("bm_MakeFormula") }

#' @title models_scores_graph
#' @description Deprecated function name for
#'   \code{\link{bm_PlotEvalMean}}
#' @param ... Additional arguments
#'
#' @name models_scores_graph-deprecated
#' @usage models_scores_graph(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{models_scores_graph}:
#' For \code{models_scores_graph} use \code{\link{bm_PlotEvalMean}}.
#'
#' @export
models_scores_graph <- function(...) { .Deprecated("bm_PlotEvalMean") }

#' @title ProbDensFunc
#' @description Deprecated function name for
#'   \code{\link{bm_PlotRangeSize}}
#' @param ... Additional arguments
#'
#' @name ProbDensFunc-deprecated
#' @usage ProbDensFunc(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{ProbDensFunc}:
#' For \code{ProbDensFunc} use \code{\link{bm_PlotRangeSize}}.
#'
#' @export
ProbDensFunc <- function(...) { .Deprecated("bm_PlotRangeSize") }

#' @title response.plot2
#' @description Deprecated function name for
#'   \code{\link{bm_PlotResponseCurves}}
#' @param ... Additional arguments
#'
#' @name response.plot2-deprecated
#' @usage response.plot2(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{response.plot2}:
#' For \code{response.plot2} use \code{\link{bm_PlotResponseCurves}}.
#'
#' @export
response.plot2 <- function(...) { .Deprecated("bm_PlotResponseCurves") }

#' @title sample.factor.levels
#' @description Deprecated function name for
#'   \code{\link{bm_SampleFactorLevels}}
#' @param ... Additional arguments
#'
#' @name sample.factor.levels-deprecated
#' @usage sample.factor.levels(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{sample.factor.levels}:
#' For \code{sample.factor.levels} use \code{\link{bm_SampleFactorLevels}}.
#'
#' @export
sample.factor.levels <- function(...) { .Deprecated("bm_SampleFactorLevels") }

#' @title sre
#' @description Deprecated function name for
#'   \code{\link{bm_SRE}}
#' @param ... Additional arguments
#'
#' @name sre-deprecated
#' @usage sre(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{sre}:
#' For \code{sre} use \code{\link{bm_SRE}}.
#'
#' @export
sre <- function(...) { .Deprecated("bm_SRE") }

#' @title .transform.outputs.list
#' @description Deprecated function name for
#'   \code{.transform_outputs_list}
#' @param ... Additional arguments
#'
#' @name .transform.outputs.list-deprecated
#' @usage .transform.outputs.list(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{.transform.outputs.list}:
#' For \code{.transform.outputs.list} use \code{.transform_outputs_list}.
#'
#' @export
.transform.outputs.list <- function(...) { .Deprecated(".transform_outputs_list") }

#' @title variables_importance
#' @description Deprecated function name for
#'   \code{\link{bm_VariablesImportance}}
#' @param ... Additional arguments
#'
#' @name variables_importance-deprecated
#' @usage variables_importance(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{variables_importance}:
#' For \code{variables_importance} use \code{\link{bm_VariablesImportance}}.
#'
#' @export
variables_importance <- function(...) { .Deprecated("bm_VariablesImportance") }

==> biomod2_4.2-6-2.tar.gz: biomod2/R/DEPRECATED.R <==
#' @title Deprecated functions in package \pkg{biomod2}.
#' @description The functions listed below are deprecated and were removed
#' in the current version. When possible, alternative functions with similar
#'   functionality are mentioned. Help pages for deprecated functions are
#'   available at \code{help("<function>-deprecated")}.
#' @name biomod2-deprecated
#' @keywords internal
#' 
#'
NULL

#' @title BIOMOD_CrossValidation
#' @description Deprecated function name for
#'   \code{\link{bm_CrossValidation}}
#' @param ... Additional arguments
#'
#' @name BIOMOD_CrossValidation-deprecated
#' @usage BIOMOD_CrossValidation(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{BIOMOD_CrossValidation}:
#' For \code{BIOMOD_CrossValidation} use \code{\link{bm_CrossValidation}}.
#'
#' @export
BIOMOD_CrossValidation <- function(...) { .Deprecated("bm_CrossValidation") }

#' @title BIOMOD_ModelingOptions
#' @description Deprecated function name for
#'   \code{\link{bm_ModelingOptions}}
#' @param ... Additional arguments
#'
#' @name BIOMOD_ModelingOptions-deprecated
#' @usage BIOMOD_ModelingOptions(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{BIOMOD_ModelingOptions}:
#' For \code{BIOMOD_ModelingOptions} use \code{\link{bm_ModelingOptions}}.
#'
#' @export
BIOMOD_ModelingOptions <- function(...) { .Deprecated("bm_ModelingOptions") }

#' @title BIOMOD_PresenceOnly
#' @description Deprecated function name for
#'   \code{\link{bm_FindOptimStat}}
#' @param ... Additional arguments
#'
#' @name BIOMOD_PresenceOnly-deprecated
#' @usage BIOMOD_PresenceOnly(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{BIOMOD_PresenceOnly}:
#' For \code{BIOMOD_PresenceOnly} use \code{\link{bm_FindOptimStat}}.
#'
#' @export
BIOMOD_PresenceOnly <- function(...) { .Deprecated("bm_FindOptimStat") }

#' @title BIOMOD_Tuning
#' @description Deprecated function name for
#'   \code{\link{bm_Tuning}}
#' @param ... Additional arguments
#'
#' @name BIOMOD_tuning-deprecated
#' @usage BIOMOD_Tuning(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{BIOMOD_Tuning}:
#' For \code{BIOMOD_Tuning} use \code{\link{bm_Tuning}}.
#'
#' @export
BIOMOD_Tuning <- function(...) { .Deprecated("bm_Tuning") }

#' @title BinaryTransformation
#' @description Deprecated function name for
#'   \code{\link{bm_BinaryTransformation}}
#' @param ... Additional arguments
#'
#' @name BinaryTransformation-deprecated
#' @usage BinaryTransformation(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{BinaryTransformation}:
#' For \code{BinaryTransformation} use \code{\link{bm_BinaryTransformation}}.
#'
#' @export
BinaryTransformation <- function(...) { .Deprecated("bm_BinaryTransformation") }

#' @title calculate.stat
#' @description Deprecated function name for
#'   \code{\link{bm_CalculateStat}}
#' @param ... Additional arguments
#'
#' @name calculate.stat-deprecated
#' @usage calculate.stat(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{calculate.stat}:
#' For \code{calculate.stat} use \code{\link{bm_CalculateStat}}.
#'
#' @export
calculate.stat <- function(...) { .Deprecated("bm_CalculateStat") }

#' @title Find.Optim.Stat
#' @description Deprecated function name for
#'   \code{\link{bm_FindOptimStat}}
#' @param ... Additional arguments
#'
#' @name Find.Optim.Stat-deprecated
#' @usage Find.Optim.Stat(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{Find.Optim.Stat}:
#' For \code{Find.Optim.Stat} use \code{\link{bm_FindOptimStat}}.
#'
#' @export
Find.Optim.Stat <- function(...) { .Deprecated("bm_FindOptimStat") }

#' @title getStatOptimValue
#' @description Deprecated function name for
#'   \code{\link{get_optim_value}}
#' @param ... Additional arguments
#'
#' @name getStatOptimValue-deprecated
#' @usage getStatOptimValue(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{getStatOptimValue}:
#' For \code{getStatOptimValue} use \code{\link{get_optim_value}}.
#'
#' @export
getStatOptimValue <- function(...) { .Deprecated("get_optim_value") }

#' @title makeFormula
#' @description Deprecated function name for
#'   \code{\link{bm_MakeFormula}}
#' @param ... Additional arguments
#'
#' @name makeFormula-deprecated
#' @usage makeFormula(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{makeFormula}:
#' For \code{makeFormula} use \code{\link{bm_MakeFormula}}.
#'
#' @export
makeFormula <- function(...) { .Deprecated("bm_MakeFormula") }

#' @title models_scores_graph
#' @description Deprecated function name for
#'   \code{\link{bm_PlotEvalMean}}
#' @param ... Additional arguments
#'
#' @name models_scores_graph-deprecated
#' @usage models_scores_graph(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{models_scores_graph}:
#' For \code{models_scores_graph} use \code{\link{bm_PlotEvalMean}}.
#'
#' @export
models_scores_graph <- function(...) { .Deprecated("bm_PlotEvalMean") }

#' @title ProbDensFunc
#' @description Deprecated function name for
#'   \code{\link{bm_PlotRangeSize}}
#' @param ... Additional arguments
#'
#' @name ProbDensFunc-deprecated
#' @usage ProbDensFunc(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{ProbDensFunc}:
#' For \code{ProbDensFunc} use \code{\link{bm_PlotRangeSize}}.
#'
#' @export
ProbDensFunc <- function(...) { .Deprecated("bm_PlotRangeSize") }

#' @title response.plot2
#' @description Deprecated function name for
#'   \code{\link{bm_PlotResponseCurves}}
#' @param ... Additional arguments
#'
#' @name response.plot2-deprecated
#' @usage response.plot2(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{response.plot2}:
#' For \code{response.plot2} use \code{\link{bm_PlotResponseCurves}}.
#'
#' @export
response.plot2 <- function(...) { .Deprecated("bm_PlotResponseCurves") }

#' @title sample.factor.levels
#' @description Deprecated function name for
#'   \code{\link{bm_SampleFactorLevels}}
#' @param ... Additional arguments
#'
#' @name sample.factor.levels-deprecated
#' @usage sample.factor.levels(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{sample.factor.levels}:
#' For \code{sample.factor.levels} use \code{\link{bm_SampleFactorLevels}}.
#'
#' @export
sample.factor.levels <- function(...) { .Deprecated("bm_SampleFactorLevels") }

#' @title sre
#' @description Deprecated function name for
#'   \code{\link{bm_SRE}}
#' @param ... Additional arguments
#'
#' @name sre-deprecated
#' @usage sre(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{sre}:
#' For \code{sre} use \code{\link{bm_SRE}}.
#'
#' @export
sre <- function(...) { .Deprecated("bm_SRE") }

#' @title .transform.outputs.list
#' @description Deprecated function name for
#'   \code{.transform_outputs_list}
#' @param ... Additional arguments
#'
#' @name .transform.outputs.list-deprecated
#' @usage .transform.outputs.list(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{.transform.outputs.list}:
#' For \code{.transform.outputs.list} use \code{.transform_outputs_list}.
#'
#' @export
.transform.outputs.list <- function(...) { .Deprecated(".transform_outputs_list") }

#' @title variables_importance
#' @description Deprecated function name for
#'   \code{\link{bm_VariablesImportance}}
#' @param ... Additional arguments
#'
#' @name variables_importance-deprecated
#' @usage variables_importance(...)
#' @seealso \code{\link{biomod2-deprecated}}
#' @keywords internal
NULL
#' @rdname biomod2-deprecated
#' @section \code{variables_importance}:
#' For \code{variables_importance} use \code{\link{bm_VariablesImportance}}.
#'
#' @export
variables_importance <- function(...) { .Deprecated("bm_VariablesImportance") }
